# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class RoomSizeDto(BaseModel):
    """RoomSizeDto

    :param metre_square: metre_square, defaults to None
    :type metre_square: float, optional
    """

    def __init__(self, metre_square: float = None):
        if metre_square is not None:
            self.metre_square = metre_square
