# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .meta import Meta
from .hotel_availability_output_dto import HotelAvailabilityOutputDto


@JsonMap({})
class ResponseOutputV2HotelAvailabilityOutputDto(BaseModel):
    """ResponseOutputV2HotelAvailabilityOutputDto

    :param meta: meta, defaults to None
    :type meta: Meta, optional
    :param result: result, defaults to None
    :type result: List[HotelAvailabilityOutputDto], optional
    """

    def __init__(
        self, meta: Meta = None, result: List[HotelAvailabilityOutputDto] = None
    ):
        if meta is not None:
            self.meta = self._define_object(meta, Meta)
        if result is not None:
            self.result = self._define_list(result, HotelAvailabilityOutputDto)
