# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .translated_string import TranslatedString


@JsonMap({})
class TruncatedString(BaseModel):
    """The translated description text of this accommodation property in the requested languages.
    The maximum number of characters returned may be limited by contract.


    :param truncate: truncate, defaults to None
    :type truncate: bool, optional
    :param translated_string: Translated description of this room. The maximum number of characters returned may be limited by contract., defaults to None
    :type translated_string: TranslatedString, optional
    """

    def __init__(
        self, truncate: bool = None, translated_string: TranslatedString = None
    ):
        if truncate is not None:
            self.truncate = truncate
        if translated_string is not None:
            self.translated_string = self._define_object(
                translated_string, TranslatedString
            )
