# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class RoomMaximumOccupancyDto(BaseModel):
    """Occupancy limits and options.

    :param adults: Maximum number of adults allowed., defaults to None
    :type adults: int, optional
    :param children: Maximum number of children allowed (children will be typically defined by being under 18 years of age)., defaults to None
    :type children: int, optional
    :param total_guests: **DEPRECATED** Total capacity of adults + children allowed., defaults to None
    :type total_guests: int, optional
    """

    def __init__(
        self, adults: int = None, children: int = None, total_guests: int = None
    ):
        if adults is not None:
            self.adults = adults
        if children is not None:
            self.children = children
        if total_guests is not None:
            self.total_guests = total_guests
