# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HotelAvailabilityOutputDto(BaseModel):
    """HotelAvailabilityOutputDto

    :param hotel_id: The unique identifier of this hotel., defaults to None
    :type hotel_id: int, optional
    :param hotel_currency_code: The currency code of the hotel's currency., defaults to None
    :type hotel_currency_code: str, optional
    :param price: The display price of the room in this hotel., defaults to None
    :type price: float, optional
    :param net_price: The net price (price without charges) of the room in this hotel., defaults to None
    :type net_price: float, optional
    """

    def __init__(
        self,
        hotel_id: int = None,
        hotel_currency_code: str = None,
        price: float = None,
        net_price: float = None,
    ):
        if hotel_id is not None:
            self.hotel_id = hotel_id
        if hotel_currency_code is not None:
            self.hotel_currency_code = hotel_currency_code
        if price is not None:
            self.price = price
        if net_price is not None:
            self.net_price = net_price
