# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class Meta(BaseModel):
    """Meta

    :param ruid: ruid, defaults to None
    :type ruid: str, optional
    """

    def __init__(self, ruid: str = None):
        if ruid is not None:
            self.ruid = ruid
