# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class LazyTranslatedString(BaseModel):
    """Translated accommodation address.

    :param fallback: fallback, defaults to None
    :type fallback: str, optional
    """

    def __init__(self, fallback: str = None):
        if fallback is not None:
            self.fallback = fallback
