# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HotelThemeTypesOutputDto(BaseModel):
    """HotelThemeTypesOutputDto

    :param theme_id: Unique ID for this theme., defaults to None
    :type theme_id: int, optional
    :param name: Name of the theme., defaults to None
    :type name: str, optional
    """

    def __init__(self, theme_id: int = None, name: str = None):
        if theme_id is not None:
            self.theme_id = theme_id
        if name is not None:
            self.name = name
