# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class NumberOfRoomsDto(BaseModel):
    """Total rooms available.

    :param bathrooms: bathrooms, defaults to None
    :type bathrooms: int, optional
    :param bedrooms: bedrooms, defaults to None
    :type bedrooms: int, optional
    :param living_rooms: living_rooms, defaults to None
    :type living_rooms: int, optional
    """

    def __init__(
        self, bathrooms: int = None, bedrooms: int = None, living_rooms: int = None
    ):
        if bathrooms is not None:
            self.bathrooms = bathrooms
        if bedrooms is not None:
            self.bedrooms = bedrooms
        if living_rooms is not None:
            self.living_rooms = living_rooms
