# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class RoomOccupancyDto(BaseModel):
    """RoomOccupancyDto

    :param allow_cribs_and_extra_beds: allow_cribs_and_extra_beds, defaults to None
    :type allow_cribs_and_extra_beds: bool, optional
    :param max_adults: max_adults, defaults to None
    :type max_adults: int, optional
    :param max_children: max_children, defaults to None
    :type max_children: int, optional
    :param max_cribs: max_cribs, defaults to None
    :type max_cribs: int, optional
    :param max_extra_beds: max_extra_beds, defaults to None
    :type max_extra_beds: int, optional
    :param max_occupancy: max_occupancy, defaults to None
    :type max_occupancy: int, optional
    """

    def __init__(
        self,
        allow_cribs_and_extra_beds: bool = None,
        max_adults: int = None,
        max_children: int = None,
        max_cribs: int = None,
        max_extra_beds: int = None,
        max_occupancy: int = None,
    ):
        if allow_cribs_and_extra_beds is not None:
            self.allow_cribs_and_extra_beds = allow_cribs_and_extra_beds
        if max_adults is not None:
            self.max_adults = max_adults
        if max_children is not None:
            self.max_children = max_children
        if max_cribs is not None:
            self.max_cribs = max_cribs
        if max_extra_beds is not None:
            self.max_extra_beds = max_extra_beds
        if max_occupancy is not None:
            self.max_occupancy = max_occupancy
