# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class PhotoUrlDto(BaseModel):
    """PhotoUrlDto

    :param large: URL of the photo image with a maximum width of 1280 pixels., defaults to None
    :type large: str, optional
    :param standard: URL of the photo image with a maximum width of 500 pixels., defaults to None
    :type standard: str, optional
    :param thumbnail: URL of the photo thumbnail image with dimensions 100x100 pixels., defaults to None
    :type thumbnail: str, optional
    :param thumbnail_large: URL of the photo thumbnail image with dimensions 300x300 pixels., defaults to None
    :type thumbnail_large: str, optional
    """

    def __init__(
        self,
        large: str = None,
        standard: str = None,
        thumbnail: str = None,
        thumbnail_large: str = None,
    ):
        if large is not None:
            self.large = large
        if standard is not None:
            self.standard = standard
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if thumbnail_large is not None:
            self.thumbnail_large = thumbnail_large
