# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class CribsAndExtraBedsDto(BaseModel):
    """Lists room options regarding adding cribs and/or extra beds.

    :param are_allowed: Flags if cots and extra beds can be placed together in the room. `true` allows both up to their maximum limits. `false` requires exclusive choice of either cots or extra beds. , defaults to None
    :type are_allowed: bool, optional
    :param maximum_number_of_cribs: Maximum number of cribs that can be added., defaults to None
    :type maximum_number_of_cribs: int, optional
    :param maximum_number_of_extra_beds: Maximum number of extra beds that can be added., defaults to None
    :type maximum_number_of_extra_beds: int, optional
    """

    def __init__(
        self,
        are_allowed: bool = None,
        maximum_number_of_cribs: int = None,
        maximum_number_of_extra_beds: int = None,
    ):
        if are_allowed is not None:
            self.are_allowed = are_allowed
        if maximum_number_of_cribs is not None:
            self.maximum_number_of_cribs = maximum_number_of_cribs
        if maximum_number_of_extra_beds is not None:
            self.maximum_number_of_extra_beds = maximum_number_of_extra_beds
