# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ExtraChargesDtoDouble(BaseModel):
    """The charge breakdown. Includes taxes and fees.

    :param excluded: Charges not included in 'book'., defaults to None
    :type excluded: float, optional
    :param included: Charges included in 'book'., defaults to None
    :type included: float, optional
    :param conditional: conditional, defaults to None
    :type conditional: float, optional
    """

    def __init__(
        self, excluded: float = None, included: float = None, conditional: float = None
    ):
        if excluded is not None:
            self.excluded = excluded
        if included is not None:
            self.included = included
        if conditional is not None:
            self.conditional = conditional
