# This file was generated by liblab | https://liblab.com/

from enum import Enum


class GetAccommodationConstantsAccept(Enum):
    """An enumeration representing different categories.

    :cvar APPLICATION_JSON: "application/json"
    :vartype APPLICATION_JSON: str
    """

    APPLICATION_JSON = "application/json"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value, GetAccommodationConstantsAccept._member_map_.values()
            )
        )
