# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ScoreDistribution(BaseModel):
    """A breakdown of all review scores into buckets 1 - 10.

    :param count: Total number of reviews in this bucket., defaults to None
    :type count: int, optional
    :param percent: Percent of score distribution that went into this bucket., defaults to None
    :type percent: float, optional
    :param score: The bucket's review score value (1 - 10)., defaults to None
    :type score: int, optional
    """

    def __init__(self, count: int = None, percent: float = None, score: int = None):
        if count is not None:
            self.count = count
        if percent is not None:
            self.percent = percent
        if score is not None:
            self.score = score
