# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class ContactDto(BaseModel):
    """Contact information of the accommodation. It can be `null` if the data is missing.

    :param email: Email address of the accommodation. It can be `null` if the data is missing., defaults to None
    :type email: dict, optional
    :param telephone: Telephone number of the accommodation. It can be `null` if the data is missing., defaults to None
    :type telephone: dict, optional
    """

    def __init__(self, email: dict = None, telephone: dict = None):
        if email is not None:
            self.email = email
        if telephone is not None:
            self.telephone = telephone
