# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class CoordinatesDto(BaseModel):
    """A signed integer number that uniquely identifies a city.

    :param latitude: Latitude., defaults to None
    :type latitude: float, optional
    :param longitude: Longitude., defaults to None
    :type longitude: float, optional
    """

    def __init__(self, latitude: float = None, longitude: float = None):
        if latitude is not None:
            self.latitude = latitude
        if longitude is not None:
            self.longitude = longitude
