# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class TranslationDto(BaseModel):
    """TranslationDto

    :param language: language, defaults to None
    :type language: str, optional
    :param name: name, defaults to None
    :type name: str, optional
    """

    def __init__(self, language: str = None, name: str = None):
        if language is not None:
            self.language = language
        if name is not None:
            self.name = name
