# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class BedDto(BaseModel):
    """Detail list of all different types and number of beds included in this configuration.

    :param bed_type: A signed integer number that uniquely identifies a bed type. Examples of bed types are: Single, Double etc., defaults to None
    :type bed_type: int, optional
    :param number_of_beds: Number of similar beds included in this configuration., defaults to None
    :type number_of_beds: int, optional
    """

    def __init__(self, bed_type: int = None, number_of_beds: int = None):
        if bed_type is not None:
            self.bed_type = bed_type
        if number_of_beds is not None:
            self.number_of_beds = number_of_beds
