# This file was generated by liblab | https://liblab.com/

from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HotelThemeTypeInputDto(BaseModel):
    """HotelThemeTypeInputDto

    :param theme_ids: Limit the results to these themes., defaults to None
    :type theme_ids: List[int], optional
    :param offset: The number of rows to offset the results by. NOTE: this needs to be 0 or a multiple of 100., defaults to None
    :type offset: int, optional
    :param row: The maximum number of rows to return. NOTE: this needs to be a multiple of 100., defaults to None
    :type row: int, optional
    """

    def __init__(
        self, theme_ids: List[int] = None, offset: int = None, row: int = None
    ):
        if theme_ids is not None:
            self.theme_ids = theme_ids
        if offset is not None:
            self.offset = offset
        if row is not None:
            self.row = row
