# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class HotelPhotoDto(BaseModel):
    """Photos specific information of the hotel.

    :param main_photo: Is this the main hotel photo., defaults to None
    :type main_photo: bool, optional
    :param url_original: Url of the photo with max width of 500 pixels., defaults to None
    :type url_original: str, optional
    """

    def __init__(self, main_photo: bool = None, url_original: str = None):
        if main_photo is not None:
            self.main_photo = main_photo
        if url_original is not None:
            self.url_original = url_original
