# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class LocalTime(BaseModel):
    """The time till when checkout can be done at this property.

    :param hour: hour, defaults to None
    :type hour: int, optional
    :param minute: minute, defaults to None
    :type minute: int, optional
    :param second: second, defaults to None
    :type second: int, optional
    :param nano: nano, defaults to None
    :type nano: int, optional
    """

    def __init__(
        self, hour: int = None, minute: int = None, second: int = None, nano: int = None
    ):
        if hour is not None:
            self.hour = hour
        if minute is not None:
            self.minute = minute
        if second is not None:
            self.second = second
        if nano is not None:
            self.nano = nano
