# This file was generated by liblab | https://liblab.com/

from enum import Enum


class GetHotelsAccept(Enum):
    """An enumeration representing different categories.

    :cvar APPLICATION_JSON_APPLICATION_XML: "application/json, application/xml"
    :vartype APPLICATION_JSON_APPLICATION_XML: str
    """

    APPLICATION_JSON_APPLICATION_XML = "application/json, application/xml"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, GetHotelsAccept._member_map_.values()))
