# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class QuestionDto(BaseModel):
    """Review scores per question.

    :param count: Number of reviewers that answered the question., defaults to None
    :type count: int, optional
    :param question: Localized question text. See language=... input parameter., defaults to None
    :type question: str, optional
    :param question_literal: Question literal., defaults to None
    :type question_literal: str, optional
    :param score: Average score that reviewers provided in response to this question., defaults to None
    :type score: float, optional
    """

    def __init__(
        self,
        count: int = None,
        question: str = None,
        question_literal: str = None,
        score: float = None,
    ):
        if count is not None:
            self.count = count
        if question is not None:
            self.question = question
        if question_literal is not None:
            self.question_literal = question_literal
        if score is not None:
            self.score = score
