# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .bed_configuration_dto import BedConfigurationDto


@JsonMap({})
class BedroomDto(BaseModel):
    """BedroomDto

    :param bed_configurations: bed_configurations, defaults to None
    :type bed_configurations: List[BedConfigurationDto], optional
    """

    def __init__(self, bed_configurations: List[BedConfigurationDto] = None):
        if bed_configurations is not None:
            self.bed_configurations = self._define_list(
                bed_configurations, BedConfigurationDto
            )
