# This file was generated by liblab | https://liblab.com/

from .utils.json_map import JsonMap
from .base import BaseModel


@JsonMap({})
class TranslatedString(BaseModel):
    """Translated description of this room. The maximum number of characters returned may be limited by contract.

    :param translations: translations, defaults to None
    :type translations: dict, optional
    """

    def __init__(self, translations: dict = None):
        if translations is not None:
            self.translations = translations
