# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .base import BaseModel
from .bed_dto import BedDto


@JsonMap({"id_": "id"})
class BedConfigurationDto(BaseModel):
    """Lists all alternative bed configurations that are supported.

    :param id_: Uniquely identifies this bed configuration., defaults to None
    :type id_: str, optional
    :param configuration: Detail list of all different types and number of beds included in this configuration., defaults to None
    :type configuration: List[BedDto], optional
    """

    def __init__(self, id_: str = None, configuration: List[BedDto] = None):
        if id_ is not None:
            self.id_ = id_
        if configuration is not None:
            self.configuration = self._define_list(configuration, BedDto)
