# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .room_info_dto import RoomInfoDto


@JsonMap({})
class RoomDataDto(BaseModel):
    """This block has room data for this hotel.

    :param room_id: room_id, defaults to None
    :type room_id: int, optional
    :param room_info: room_info, defaults to None
    :type room_info: RoomInfoDto, optional
    """

    def __init__(self, room_id: int = None, room_info: RoomInfoDto = None):
        if room_id is not None:
            self.room_id = room_id
        if room_info is not None:
            self.room_info = self._define_object(room_info, RoomInfoDto)
