# This file was generated by liblab | https://liblab.com/

from __future__ import annotations
from .utils.json_map import JsonMap
from .base import BaseModel
from .contact_dto import ContactDto


@JsonMap({})
class ContactsDto(BaseModel):
    """Contact information of the accommodation.

    :param general: Contact information of the accommodation. It can be `null` if the data is missing., defaults to None
    :type general: ContactDto, optional
    :param reservations: Contact information of the accommodation. It can be `null` if the data is missing., defaults to None
    :type reservations: ContactDto, optional
    """

    def __init__(self, general: ContactDto = None, reservations: ContactDto = None):
        if general is not None:
            self.general = self._define_object(general, ContactDto)
        if reservations is not None:
            self.reservations = self._define_object(reservations, ContactDto)
